@@ -19,7 +19,7 @@ def _get_span_trace_id(span: Span) -> str | None:
 
 
 def pre_request_trace(  # type: ignore[no-untyped-def]
-    worker, req, tracer_provider=None
+    worker, req, tracer_provider=None, ignored_uris=None
 ):
     """
     Gunicorn pre request hook function for tracing
@@ -42,10 +42,13 @@ def pre_request_trace(  # type: ignore[no-untyped-def]
             http_req_url=req.uri,
             http_req_scheme=req.scheme,
             http_req_flavor=".".join(str(v) for v in req.version),
+            http_req_server_ip=None,
+            http_req_server_port=None,
             http_req_client_ip=peer_ip,
             http_req_client_port=peer_port,
             http_req_headers=request_headers,
-            span_name=None,
+            span_name="gunicorn.request",
+            ignored_urls=ignored_uris,
         )
 
         # This is usually used as a context manager, but we can't do that here
